# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates a trigger for the player's
about dialog.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE

class Trigger(GObject):
	"""
	This class creates an object that shows the about dialog.
	"""

	__gsignals__ = {
		"destroy": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
	}

	def __init__(self, player):
		"""
		Initialize the trigger.

		@param self: Reference to the Trigger instance.
		@type self: An Trigger object.

		@param player: Reference to the text player.
		@type player: An player object.
		"""
		GObject.__init__(self)
		self.__init_attributes(player)
		self.__create_trigger()
		self.__signal_id_1 = self.__trigger.connect("activate", self.__show_about_dialog_cb)
		self.__signal_id_2 = self.connect_after("destroy", self.__destroy_cb)

	def __init_attributes(self, player):
		"""
		Initialize the trigger's attributes.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.

		@param player: Reference to the text player.
		@type player: An player object.
		"""
		self.__player = player
		self.__about_dialog = None
		self.__trigger = None
		self.__signal_id_1 = None
		self.__signal_id_2 = None
		return

	def __create_trigger(self):
		"""
		Create the trigger.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.
		"""
		# Trigger to show the about dialog.
		from Striim.Trigger import Trigger
		self.__trigger = Trigger("show_about_dialog")
		self.__player.add_trigger(self.__trigger)
		return

	def __show_about_dialog_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.

		@param trigger: An object to show the document browser.
		@type trigger: A Trigger object.
		"""
		try:
			self.__about_dialog.show_dialog()
		except AttributeError:
			from AboutDialog import StriimAboutDialog
			self.__about_dialog = StriimAboutDialog(self.__player)
			self.__about_dialog.show_dialog()
		return

	def __destroy_cb(self, trigger):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the Trigger instance.
		@type self: An Trigger object.

		@param trigger: Reference to the Trigger instance.
		@type trigger: An Trigger object.
		"""
		self.__player.remove_trigger(self.__trigger)
		from Striim.utils import disconnect_signal, delete_attributes
		disconnect_signal(self.__signal_id_1, self.__trigger)
		disconnect_signal(self.__signal_id_2, self)
		if self.__about_dialog:
			self.__about_dialog.emit("delete")
		delete_attributes(self)
		del self
		self = None
		return

	def destroy(self):
		self.emit("destroy")
		return
